/*
	(C) 1995-96 AROS - The Amiga Research OS
	$Id: movewindow.c,v 1.4 2010/12/17 20:18:29 jacadcaps Exp $
 
	Desc: Move a window around on the screen
	Lang: english
*/
#include "intuition_intern.h"
#include "inputhandler_actions.h"
#include "mosmisc.h"

struct MoveWindowActionMsg
{
	struct IntuiActionMsg msg;
	struct Window *window;
	WORD dx;
	WORD dy;
};

static VOID int_movewindow(struct MoveWindowActionMsg *msg,
						   struct IntuitionBase *IntuitionBase);


/*****************************************************************************
 
	NAME */
#include <proto/intuition.h>

AROS_LH3(void, MoveWindow,

		 /*  SYNOPSIS */
		 AROS_LHA(struct Window *, window, A0),
		 AROS_LHA(LONG           , dx, D0),
		 AROS_LHA(LONG           , dy, D1),

		 /*  LOCATION */
		 struct IntuitionBase *, IntuitionBase, 28, Intuition)

/*  FUNCTION
	Change the position of a window on the screen.
 
	INPUTS
	window - Move this window
	dx, dy - Move it that many pixels along the axis (right, down)
 
	RESULT
	The window will move when the next input event will be received.
 
	NOTES
 
	EXAMPLE
 
	BUGS
 
	SEE ALSO
	SizeWindow()
 
	INTERNALS
 
	HISTORY
 
*****************************************************************************/
{
	AROS_LIBFUNC_INIT
	AROS_LIBBASE_EXT_DECL(struct IntuitionBase *,IntuitionBase)

	EXTENDWORD(dx);
	EXTENDWORD(dy);

#ifdef __MORPHOS__
	if (IsDuringSelfResize(IntuitionBase)) return;
#endif

	if (window && (dx || dy))
	{
		struct MoveWindowActionMsg msg;

		msg.window = window;
		msg.dx = dx;
		msg.dy = dy;

		//DoASyncAction((APTR)int_movewindow, &msg.msg, sizeof(msg), IntuitionBase);
		DoSyncAction((APTR)int_movewindow, &msg.msg, IntuitionBase);
	}

	AROS_LIBFUNC_EXIT
} /* MoveWindow */

static VOID int_movewindow(struct MoveWindowActionMsg *msg,
						   struct IntuitionBase *IntuitionBase)
{
	struct Window *window = msg->window;

//#ifdef __MORPHOS__
//	  if (IsWindowInDragArea(window->LeftEdge + msg->dx,
//							 window->TopEdge + msg->dy,
//							 window,
//							 IntuitionBase))
//	  {
//#endif
		DoMoveSizeWindow(window,
						 window->LeftEdge + msg->dx, window->TopEdge + msg->dy,
						 window->Width, window->Height, 0, IntuitionBase);
//#ifdef __MORPHOS__
//	  } else {
//		  DoMoveSizeWindow(window, window->LeftEdge, window->TopEdge, window->Width, window->Height, TRUE, IntuitionBase);
//	  }
//#endif
}
